@@ -42,6 +42,7 @@
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkmessagedialog.h>
+#include <gtk/gtkexpander.h>
 #include <glade/glade-xml.h>
 
 #include "gbf-i18n.h"
@@ -1031,6 +1032,8 @@ gbf_am_properties_get_group_widget (GbfAmProject *project,
 	GbfAmConfigMapping *config;
 	GbfAmConfigValue *value;
 	GtkWidget *table;
+	GtkWidget *table_cflags;
+	GtkWidget *expander_cflags;
 	GError *err = NULL;
 	
 	g_return_val_if_fail (GBF_IS_AM_PROJECT (project), NULL);
@@ -1068,19 +1071,41 @@ gbf_am_properties_get_group_widget (GbfAmProject *project,
 	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
 				_("Includes:"), NULL, "includes",
 				table, 1);
+	/* CFlags */
+	table_cflags = gtk_table_new(6,2, FALSE);
+	expander_cflags = gtk_expander_new(_("Compiler Settings"));
+	gtk_table_attach (GTK_TABLE (table), expander_cflags, 0, 2, 3, 4,
+				  GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 3);
+	gtk_container_add(GTK_CONTAINER(expander_cflags), table_cflags);
+	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("C compiler flags:"), NULL, "amcflags", table_cflags, 0);
+	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("C preprocessor flags"), NULL, "amcppflags", table_cflags, 1);
+	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("C++ compiler flags"), NULL, "amcxxflags", table_cflags, 2);
+	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("gcj compiler flags (ahead-of-time)"), NULL, "amgcjflags", table_cflags, 3);
+	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("Java compiler flags (just-in-time)"), NULL, "amjavaflags", table_cflags, 4);
+	add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("Fortran compiler flags:"), NULL, "amfflags", table_cflags, 5);
+				
 	/* Install directories */
 	value = gbf_am_config_mapping_lookup (config, "installdirs");
 	if (value) {
 		GtkWidget *table2, *frame, *lab;
+		char *text;
 		frame = gtk_frame_new ("");
 		
 		lab = gtk_frame_get_label_widget (GTK_FRAME(frame));
-		gtk_label_set_markup (GTK_LABEL(lab),
-				      _("<b>Install directories:</b>"));
+		text = g_strdup_printf ("<b>%s</b>", _("Install directories:"));
+		gtk_label_set_markup (GTK_LABEL(lab), text);
+		g_free (text);
+				      
 		gtk_frame_set_shadow_type (GTK_FRAME (frame),
 					   GTK_SHADOW_NONE);
 		gtk_widget_show (frame);
-		gtk_table_attach (GTK_TABLE (table), frame, 0, 2, 2, 3,
+		gtk_table_attach (GTK_TABLE (table), frame, 0, 2, 4, 5,
 				  GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 3);
 		table2 = gtk_table_new (0, 0, FALSE);
 		gtk_widget_show (table2);
@@ -1123,6 +1148,8 @@ gbf_am_properties_get_target_widget (GbfAmProject *project,
 	GbfAmConfigMapping *installdirs;
 	GbfAmConfigValue *installdirs_val, *dir_val;
 	GtkWidget *table;
+	GtkWidget *table_cflags;
+	GtkWidget *expander_cflags;
 	GError *err = NULL;
 	
 	g_return_val_if_fail (GBF_IS_AM_PROJECT (project), NULL);
@@ -1147,7 +1174,7 @@ gbf_am_properties_get_target_widget (GbfAmProject *project,
 							target->group_id,
 							NULL);
 	
-	table = gtk_table_new (7, 2, FALSE);
+	table = gtk_table_new (9, 2, FALSE);
 	g_object_ref (table);
 	g_object_set_data (G_OBJECT (table), "__project", project);
 	g_object_set_data_full (G_OBJECT (table), "__config", config,
@@ -1219,23 +1246,49 @@ gbf_am_properties_get_target_widget (GbfAmProject *project,
 	if (target->type && (strcmp (target->type, "program") == 0 ||
 			     strcmp (target->type, "shared_lib") == 0 ||
 			     strcmp (target->type, "static_lib") == 0)) {
+		/* CFLAGS */
+		const gchar* lib_type;
+		table_cflags = gtk_table_new(5,2, FALSE);
+		expander_cflags = gtk_expander_new(_("Compiler Settings"));
+		gtk_table_attach (GTK_TABLE (table), expander_cflags, 0, 2, 4, 5,
+				  GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 3);
+		gtk_container_add(GTK_CONTAINER(expander_cflags), table_cflags);
+		add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("C compiler flags:"), NULL, "cflags", table_cflags, 0);
+		add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("C preprocessor flags"), NULL, "cppflags", table_cflags, 1);
+		add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("C++ compiler flags"), NULL, "cxxflags", table_cflags, 2);
+		add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("gcj compiler flags (ahead-of-time)"), NULL, "gcjflags", table_cflags, 3);
+		add_configure_property (project, config, GBF_AM_CONFIG_ENTRY,
+				_("Fortran compiler flags:"), NULL, "amfflags", table_cflags, 4);
 		/* LDFLAGS */
 		add_configure_property (project, config,
 					GBF_AM_CONFIG_ENTRY,
 					_("Linker flags:"), NULL,
-					"ldflags", table, 4);
+					"ldflags", table, 6);
 		
 		/* LDADD */
+		/* We need to care here if it is ldadd or libadd #476315 */
+		if (strcmp (target->type, "shared_lib") == 0)
+		{
+			lib_type = "libadd";
+		}
+		else
+		{
+			lib_type = "ldadd";
+		}			     
 		add_configure_property (project, config,
 					GBF_AM_CONFIG_ENTRY,
 					_("Libraries:"), NULL,
-					"ldadd", table, 5);
+					lib_type, table, 7);
 		
 		/* DEPENDENCIES */
 		add_configure_property (project, config,
 					GBF_AM_CONFIG_ENTRY,
 					_("Dependencies:"), NULL,
-					"explicit_deps", table, 6);
+					"explicit_deps", table, 8);
 	}
 	gtk_widget_show_all (table);
 	gbf_project_target_free (target);
